#[repr(u8)]pub enum Fauto {
Show 16 variants
MANUAL = 0,
AUTOMATIC = 1,
_RESERVED_2 = 2,
_RESERVED_3 = 3,
_RESERVED_4 = 4,
_RESERVED_5 = 5,
_RESERVED_6 = 6,
_RESERVED_7 = 7,
_RESERVED_8 = 8,
_RESERVED_9 = 9,
_RESERVED_a = 10,
_RESERVED_b = 11,
_RESERVED_c = 12,
_RESERVED_d = 13,
_RESERVED_e = 14,
_RESERVED_f = 15,
}Variants
MANUAL = 0
Manual fault clearing. PWM outputs disabled by this fault are not enabled until FSTS[FFLAGx] is clear at the start of a half cycle or full cycle depending the states of FSTS[FHALF] and FSTS[FFULL]. If neither FFULL nor FHALF is set, then the fault condition cannot be cleared. This is further controlled by FCTRL[FSAFE].
AUTOMATIC = 1
Automatic fault clearing. PWM outputs disabled by this fault are enabled when FSTS[FFPINx] is clear at the start of a half cycle or full cycle depending on the states of FSTS[FHALF] and FSTS[FFULL] without regard to the state of FSTS[FFLAGx]. If neither FFULL nor FHALF is set, then the fault condition cannot be cleared.
_RESERVED_2 = 2
_RESERVED_3 = 3
_RESERVED_4 = 4
_RESERVED_5 = 5
_RESERVED_6 = 6
_RESERVED_7 = 7
_RESERVED_8 = 8
_RESERVED_9 = 9
_RESERVED_a = 10
_RESERVED_b = 11
_RESERVED_c = 12
_RESERVED_d = 13
_RESERVED_e = 14
_RESERVED_f = 15
Implementations