#[repr(u8)]pub enum InitSel {
PWM_X = 0,
MASTER_RELOAD = 1,
MASTER_SYNC = 2,
EXT_SYNC = 3,
}Variants
PWM_X = 0
Local sync (PWM_X) causes initialization.
MASTER_RELOAD = 1
Master reload from submodule 0 causes initialization. This setting should not be used in submodule 0 as it will force the INIT signal to logic 0. The submodule counter will only reinitialize when a master reload occurs.
MASTER_SYNC = 2
Master sync from submodule 0 causes initialization. This setting should not be used in submodule 0 as it will force the INIT signal to logic 0.
EXT_SYNC = 3
EXT_SYNC causes initialization.
Implementations